@@ -1,14 +1,14 @@
 #!/usr/bin/perl
 use strict; use warnings;
 
+use lib 'lib';
 use Google::Adwords::AccountService;
 
 # Initialize client accounts in the sandbox
 
 my $email = '';
 my $password = '';
-my $currency = '';
-my $client_num = '1';
+my $currency = 'INR';
 
 my $service = Google::Adwords::AccountService->new();
 
@@ -16,6 +16,7 @@ my $service = Google::Adwords::AccountService->new();
 $service->email($email)
         ->password($password)
         ->developerToken($email. '++' . $currency)
+        #->api_version('v7')
         ->use_sandbox(1)
         ->debug(1)
 ;
